import React, { useState, useEffect } from "react";
import Modal from "react-bootstrap/Modal";
import Button from "react-bootstrap/Button";
import Table from "react-bootstrap/Table";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faTrash, faPlus } from "@fortawesome/free-solid-svg-icons";

function VehicleTypes() {
  const [vehicleTypes, setVehicleTypes] = useState<
    { id: number; name: string; seats: number; image: string }[]
  >([]);
  const [add, setAdd] = useState(false);
  const [removeId, setRemoveId] = useState<number | null>(null);

  useEffect(() => {
    reloadData();
  });

  const reloadData = () => {
    fetch("/api/vehicleType", {
      method: "GET",
      credentials: "same-origin",
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => response.json())
      .then((data) => setVehicleTypes(data))
      .catch((e) => console.log("Error while loading vehicle type\n:", e));
  };
  const addType = (type: any) => {
    fetch("/api/vehicleType", {
      method: "POST",
      credentials: "same-origin",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify(type),
    }).then(() => reloadData());
  };
  const removeType = () => {
    fetch("/api/vehicleType/" + removeId, {
      method: "DELETE",
      credentials: "same-origin",
      headers: {
        "Content-Type": "application/json",
      },
    }).then(() => {
      reloadData();
      setRemoveId(null);
    });
  };
  const getRemoveDialog = () => {
    return (
      <div className={"modalWrapper"}>
        <Modal.Dialog>
          <Modal.Header
            closeButton
            onClick={() => {
              setRemoveId(null);
            }}
          >
            <Modal.Title>Remove Vehicle Type</Modal.Title>
          </Modal.Header>
          <Modal.Body>
            <p>
              Remove VehicleType "
              {/* {vehicleTypes.find((x) => x.id == removeId).name}"? */}
            </p>
          </Modal.Body>
          <Modal.Footer>
            <Button
              variant="secondary"
              onClick={() => {
                setRemoveId(null);
              }}
            >
              Close
            </Button>
            <Button
              variant="danger"
              onClick={() => {
                removeType();
              }}
            >
              Delete
            </Button>
          </Modal.Footer>
        </Modal.Dialog>
      </div>
    );
  };
  const getAddDialog = () => {
    return (
      <div className={"modalWrapper"}>
        <Modal.Dialog>
          <Modal.Header
            closeButton
            onClick={() => {
              setAdd(false);
            }}
          >
            <Modal.Title>New Vehicle Type</Modal.Title>
          </Modal.Header>
          <Modal.Body>
            <p>Add VehicleType?</p>
            TODO
          </Modal.Body>
          <Modal.Footer>
            <Button
              variant="secondary"
              onClick={() => {
                setAdd(false);
              }}
            >
              Close
            </Button>
            <Button
              variant="primary"
              onClick={() => {
                addType({ name: "ABC", seats: 2 });
              }}
            >
              Add
            </Button>
          </Modal.Footer>
        </Modal.Dialog>
      </div>
    );
  };

  return (
    <div>
      <div className={"menuBarTable"}>
        <Button size="sm" variant="dark" title="Add Type">
          <FontAwesomeIcon
            className={"text-center"}
            onClick={() => {
              setAdd(true);
            }}
            icon={faPlus}
          />
        </Button>
      </div>
      <Table striped bordered hover variant="dark">
        <thead>
          <tr>
            <th>#</th>
            <th>Name</th>
            <th>Seats</th>
            <th> </th>
          </tr>
        </thead>
        <tbody>
          {vehicleTypes.map((t) => (
            <tr key={t.id}>
              <td>{t.id}</td>
              <td>{t.name}</td>
              <td>{t.seats}</td>
              <td className={"text-center"}>
                <FontAwesomeIcon
                  className={"text-danger text-center iconHover"}
                  onClick={() => {
                    setRemoveId(t.id);
                  }}
                  title="Remove"
                  icon={faTrash}
                />
              </td>
            </tr>
          ))}
        </tbody>
      </Table>
      {removeId != null && getRemoveDialog()}
      {add && getAddDialog()}
    </div>
  );
}

export default VehicleTypes;
